@@ -18,6 +18,7 @@
 #include <qapplication.h>
 #include <qclipboard.h>
 #include <qdatetime.h>
+#include <qtoolbutton.h>
 
 #include <klocale.h>
 #include <kpopupmenu.h>
@@ -28,6 +29,10 @@
 FavoriteListView::FavoriteListView( QWidget* parent, const char* name )
         : Kita::ThreadListView( parent, name )
 {
+    subjectList->addColumn( i18n( "Board" ) );
+
+    ReloadButton->hide();
+
     connect( subjectList, SIGNAL( clicked( QListViewItem* ) ),
              SLOT( loadThread( QListViewItem* ) ) );
     connect( subjectList, SIGNAL( contextMenuRequested( QListViewItem*, const QPoint&, int ) ),
@@ -61,14 +66,20 @@ void FavoriteListView::update()
         since.setTime_t( KURL( thread->datURL() ).fileName().section( '.', 0, 0 ).toInt() );
 
         int readNum = cache->readNum( thread->datURL() );
-        int resNum = cache->resNum( thread->datURL() );  // TODO unused variables.
+        int resNum = KitaThreadInfo::resNum( thread->datURL() );
 
         KListViewItem* item = new KListViewItem( subjectList );
-        item->setText( Row_Board, thread->boardName() );
-        item->setText( Row_Subject, thread->name() );
-        item->setText( Row_Read, QString( "%1" ).arg( readNum, 4 ) );
-        item->setText( Row_Since, since.toString( "yy/MM/dd hh:mm" ) );
-        item->setText( Row_DatURL, thread->datURL() );
+        item->setText( Col_Board, thread->boardName() );
+        item->setText( Col_Subject, thread->name() );
+        item->setText( Col_Read, QString( "%1" ).arg( readNum, 4 ) );
+        if ( resNum > 0 ) {
+            item->setText( Col_ResNum, QString( "%1" ).arg( resNum, 4 ) );
+            if ( resNum != readNum ) {
+                item->setText( Col_Unread, QString( "%1" ).arg( resNum - readNum, 4 ) );
+            }
+        }
+        item->setText( Col_Since, since.toString( "yy/MM/dd hh:mm" ) );
+        item->setText( Col_DatURL, thread->datURL() );
     }
 }
 
@@ -83,7 +94,7 @@ void FavoriteListView::loadThread( QListViewItem* item )
     for ( ; it.current(); ++it ) {
         const Kita::Thread* thread = it.current();
 
-        if ( thread->datURL() == item->text( Row_DatURL ) ) {
+        if ( thread->datURL() == item->text( Col_DatURL ) ) {
             emit signalShowThread( thread );
         }
     }
@@ -92,8 +103,11 @@ void FavoriteListView::loadThread( QListViewItem* item )
 void FavoriteListView::updateThread( const Kita::Thread* updated_thread )
 {
     for ( QListViewItem * item = subjectList->firstChild(); item; item = item->nextSibling() ) {
-        if ( item->text( Row_DatURL ) == updated_thread->datURL() ) {
-            item->setText( Row_ResNum, QString( "%1" ).arg( updated_thread->resNum(), 4 ) );
+        if ( item->text( Col_DatURL ) == updated_thread->datURL() ) {
+            int resNum = updated_thread->resNum();
+            int readNum = KitaThreadInfo::readNum( updated_thread->datURL() );
+            item->setText( Col_ResNum, QString( "%1" ).arg( resNum, 4 ) );
+            item->setText( Col_Read, QString( "%1" ).arg( readNum, 4 ) );
         }
     }
 }
@@ -110,7 +124,7 @@ void FavoriteListView::slotContextMenuRequested( QListViewItem* item, const QPoi
     popup.insertItem( i18n( "Open with new tab" ), 1 );
     popup.insertItem( i18n( "Copy title and URL" ), 2 );
 
-    Kita::Thread* thread = Kita::Thread::getByURL( item->text( Row_DatURL ) );
+    Kita::Thread* thread = Kita::Thread::getByURL( item->text( Col_DatURL ) );
 
     QClipboard* clipboard = QApplication::clipboard();
 
