@@ -25,6 +25,7 @@
 #include <kio/netaccess.h>
 
 // include files for KDE
+#include <kwin.h>
 #include <kfilterdev.h>
 #include <klistview.h>
 #include <kiconloader.h>
@@ -48,6 +49,8 @@ KitaSubjectView::KitaSubjectView( QWidget* parent, const char* name )
              SLOT( loadThread( QListViewItem* ) ) );
     connect( subjectList, SIGNAL( returnPressed( QListViewItem* ) ),
              SLOT( loadThread( QListViewItem* ) ) );
+    connect( ReloadButton, SIGNAL( clicked() ),
+             SLOT( slotReloadButton() ) );
 }
 
 KitaSubjectView::~KitaSubjectView()
@@ -76,18 +79,20 @@ void KitaSubjectView::loadThread( QListViewItem* item )
 {
     if ( ! item ) return ;
 
-    KURL datURL = item->text( Row_DatURL );
+    KURL datURL = item->text( Col_DatURL );
 
     Kita::Board::setName( Kita::datToBoard( datURL.url() ), m_board->name() );
-    Kita::Thread::setName( datURL.url(), item->text( Row_Subject ) );
+    Kita::Thread::setName( datURL.url(), item->text( Col_Subject ) );
     Kita::Thread* thread = Kita::Thread::getByURL( datURL.url() );
 
-    KitaThreadInfo::setResNum( datURL.url(), item->text( Row_Read ).toInt() );
     emit signalShowThread( thread );
 }
 
 void KitaSubjectView::loadBoard( const Kita::Board* board )
 {
+    setActiveWindow();
+    topLevelWidget()->raise();
+
     // reset member variables.
     // FIXME: FavoriteListView::update()˥ԡ
     {
@@ -113,22 +118,27 @@ void KitaSubjectView::loadBoard( const Kita::Board* board )
         int readNum = cache->readNum( thread->datURL() );
         int resNum = thread->resNum();
 
-        KListViewItem* item = new KListViewItem( subjectList );
-        item->setText( Row_ID, QString( "%1" ).arg( i + 1, 4 ) );
-        item->setText( Row_Subject, thread->name() );
-        item->setText( Row_ResNum, QString( "%1" ).arg( resNum, 4 ) );
-        item->setText( Row_Read, ( readNum > 0 ) ? QString( "%1" ).arg( readNum, 4 ) : QString( "" ) );
-        item->setText( Row_Unread, ( readNum > 0 && resNum != readNum ) ? QString( "%1" ).arg( resNum - readNum, 4 ) : QString( "" ) );
-        item->setText( Row_Board, thread->boardName() );
-        item->setText( Row_Since, since.toString( "yy/MM/dd hh:mm" ) );
-        item->setText( Row_DatURL, thread->datURL() );
+        Kita::ThreadListViewItem* item = new Kita::ThreadListViewItem( subjectList );
+        item->setText( Col_ID, QString( "%1" ).arg( i + 1, 4 ) );
+        item->setText( Col_Subject, thread->name() );
+        item->setText( Col_ResNum, QString( "%1" ).arg( resNum, 4 ) );
+        item->setText( Col_Read, ( readNum > 0 ) ? QString( "%1" ).arg( readNum, 4 ) : QString( "" ) );
+        item->setText( Col_Unread, ( readNum > 0 && resNum != readNum ) ? QString( "%1" ).arg( resNum - readNum, 4 ) : QString( "" ) );
+        item->setText( Col_Board, thread->boardName() );
+        item->setText( Col_Since, since.toString( "yy/MM/dd hh:mm" ) );
+        item->setText( Col_DatURL, thread->datURL() );
 
+        // FIXME: updateThread˥ԡƤ
         if ( readNum > 0 && resNum != readNum ) {
             // ̤ɤ
-            item->setPixmap( Row_Mark, SmallIcon( "unread" ) );
+            item->setPixmap( Col_Mark, SmallIcon( "unread" ) );
+            item->setText( Col_MarkOrder, "2" );
         } else if ( readNum > 0 ) {
             // 
-            item->setPixmap( Row_Mark, SmallIcon( "read" ) );
+            item->setPixmap( Col_Mark, SmallIcon( "read" ) );
+            item->setText( Col_MarkOrder, "1" );
+        } else {
+            item->setText( Col_MarkOrder, "0" );
         }
     }
 
@@ -137,6 +147,8 @@ void KitaSubjectView::loadBoard( const Kita::Board* board )
     }
     emit loadBoardCompleted( m_board->url() );
 
+    subjectList->setSorting( Col_ID );
+
     subjectList->setFocus();
 }
 
@@ -148,11 +160,24 @@ void KitaSubjectView::setFont( const QFont& font )
 void KitaSubjectView::updateThread( const Kita::Thread* updated_thread )
 {
     for ( QListViewItem * item = subjectList->firstChild(); item; item = item->nextSibling() ) {
-        if ( item->text( Row_DatURL ) == updated_thread->datURL() ) {
-            int resNum = item->text( Row_ResNum ).toInt();
-            int readNum = updated_thread->resNum();
-            item->setText( Row_Read, QString( "%1" ).arg( readNum, 4 ) );
-            item->setText( Row_Unread, readNum > 0 && resNum != readNum ? QString( "%1" ).arg( resNum - readNum, 4 ) : QString( "" ) );
+        if ( item->text( Col_DatURL ) == updated_thread->datURL() ) {
+            int resNum = updated_thread->resNum();
+            int readNum = KitaThreadInfo::readNum( updated_thread->datURL() );
+            item->setText( Col_ResNum, QString( "%1" ).arg( resNum, 4 ) );
+            item->setText( Col_Read, QString( "%1" ).arg( readNum, 4 ) );
+            item->setText( Col_Unread, readNum > 0 && resNum != readNum ? QString( "%1" ).arg( resNum - readNum, 4 ) : QString( "" ) );
+
+            if ( readNum > 0 && resNum != readNum ) {
+                // ̤ɤ
+                item->setPixmap( Col_Mark, SmallIcon( "unread" ) );
+                item->setText( Col_MarkOrder, "2" );
+            } else if ( readNum > 0 ) {
+                // 
+                item->setPixmap( Col_Mark, SmallIcon( "read" ) );
+                item->setText( Col_MarkOrder, "1" );
+            } else {
+                item->setText( Col_MarkOrder, "0" );
+            }
         }
     }
 }
@@ -168,7 +193,7 @@ void KitaSubjectView::slotContextMenuRequested( QListViewItem* item, const QPoin
     popup.insertItem( i18n( "Open with new tab" ), 1 );
     popup.insertItem( i18n( "Copy title and URL" ), 2 );
 
-    Kita::Thread* thread = Kita::Thread::getByURL( item->text( Row_DatURL ) );
+    Kita::Thread* thread = Kita::Thread::getByURL( item->text( Col_DatURL ) );
 
     QClipboard* clipboard = QApplication::clipboard();
 
@@ -186,3 +211,10 @@ void KitaSubjectView::slotContextMenuRequested( QListViewItem* item, const QPoin
         break;
     }
 }
+
+void KitaSubjectView::slotReloadButton()
+{
+    if ( m_board ) {
+        loadBoard( m_board );
+    }
+}
