@@ -27,12 +27,19 @@ class URLConvertTest : public CppUnit::TestFixture {
   CPPUNIT_TEST_SUITE_END();
 
   QString m_datURL;
+  QString m_datURL_k2ch;
   QString m_threadURL;
+  QString m_threadURL_k2ch;
   QString m_threadURL2;
+  QString m_threadURL2_k2ch;
   QString m_subjectURL;
+  QString m_subjectURL_k2ch;
   QString m_boardURL;
+  QString m_boardURL_k2ch;
   QString m_boardURL2;
+  QString m_boardURL2_k2ch;
   QString m_cachePath;
+  QString m_cachePath_k2ch;
 
 public:
   void setUp();
