@@ -164,8 +164,13 @@ void Thread::setName( const QString& datURL, const QString& threadName )
         m_threadDict = new QDict<Thread>();
     }
 
-    Thread* newThread = new Thread( datURL, threadName );
-    m_threadDict->replace( datURL, newThread );
+    if ( m_threadDict->find( datURL ) ) {
+        Thread * thread = getByURL( datURL );
+        thread->m_threadName = threadName;
+    } else {
+        Thread* newThread = new Thread( datURL, threadName );
+        m_threadDict->insert( datURL, newThread );
+    }
 
     return ;
 }
@@ -515,11 +520,6 @@ void ThreadAccess::slotRedirection( KIO::Job *, const KURL & newURL )
     QString backupPath = cachePath + ".kita_backup";
     KIO::NetAccess::copy( backupPath, cachePath );
     KIO::NetAccess::del( backupPath );
-/*
-    kdDebug() << "Redirected to newURL: " << newURL.url() << endl;
-    Kita::Board::setName( datToBoard( newURL.url() ), m_thread->boardName() );
-    m_thread = Kita::Thread::getByURL( newURL.url() );
-    emit redirection( newURL.url() );*/
 }
 
 void ThreadAccess::slotReceiveThreadData( KIO::Job*, const QByteArray& data )
