@@ -146,6 +146,9 @@ void KitaThreadView::slotDOMNodeActivated( const DOM::Node& node )
 
 void KitaThreadView::showThread( const Kita::Thread* thread )
 {
+    setActiveWindow();
+    topLevelWidget()->raise();
+
     { //reset member variables associated with a thread.
         m_threadPart->reset();
     }
@@ -182,11 +185,11 @@ void KitaThreadView::update( const QString& result )
     int step = 0;
     int divide = total / ( 100 / 5 );
     int next = divide;
-    int prevResNum = m_thread->resNum();
-    QProgressDialog* progress = new QProgressDialog( parentWidget() );
+    int prevReadNum = KitaThreadInfo::readNum( m_thread->datURL() );
+/*    QProgressDialog* progress = new QProgressDialog( parentWidget() );
     progress->setTotalSteps( static_cast<int>( total * 0.7 ) );
     progress->setLabelText( "Parse DAT file....." );
-    progress->show();
+    progress->show();*/
 
     text += "<html><head>";
     text += "</head>";
@@ -214,29 +217,30 @@ void KitaThreadView::update( const QString& result )
         }
         text += comment.toHtml( num, KitaConfig::showMailAddress() );
 
-        if ( prevResNum == num ) {
+        if ( prevReadNum == num ) {
             QTextCodec * codec = QTextCodec::codecForName( "euc-jp" );
             text += codec->toUnicode( kokomade_yonda );
         }
 
         if ( ( step += line.length() ) > next ) {
-            progress->setProgress( step );
+//            progress->setProgress( step );
             next += divide;
         }
     }
-    delete progress;
+//    delete progress;
 
     m_thread->setResNum( num );
+    KitaThreadInfo::setReadNum( m_thread->datURL(), num );
     emit thread( m_thread );
 
     setSubjectLabel( m_thread->boardName(), m_thread->name() );
 
-    text += footer( prevResNum );
+    text += footer();
     text += "</body></html>";
 
     m_threadPart->displayContents( text, m_thread->datURL() );
     // FIXME: ⤦äȤޤȤˡȤ
-    m_threadPart->gotoURL( m_thread, QMIN( QMAX( prevResNum, 1 ), m_thread->resNum() ) );
+    m_threadPart->gotoURL( m_thread, QMIN( QMAX( prevReadNum, 1 ), KitaThreadInfo::resNum( m_thread->datURL() ) ) );
     updateButton();
 
     emit showThreadCompleted( m_thread->url() );
@@ -258,7 +262,7 @@ void KitaThreadView::updateButton()
     }
 }
 
-const QString KitaThreadView::footer( int prevResNum ) const
+const QString KitaThreadView::footer() const
 {
     QString text;
     int target;
