@@ -68,7 +68,7 @@ protected slots:
     void slotPopupMenu( KXMLGUIClient*, const QPoint&, const KURL&, const QString&, mode_t );
     void slotOpenURLRequest( const KURL&, const KParts::URLArgs& );
 
-private:    // Private attributes
+private:     // Private attributes
     Kita::ThreadAccess* m_access;
     Kita::Thread* m_thread;
     KitaHTMLPart* m_threadPart;
@@ -79,7 +79,7 @@ private:    // Private attributes
     KURL filterReadCGI( const KURL& );
     void setSubjectLabel( const QString& boardName, const QString& threadName );
     KitaWriteDialog* openDialog( const Kita::PostInfo& info );
-    const QString footer( int ) const;
+    const QString footer() const;
     QStringList parseSearchQuery( const QString& input ) const;
     void update( const QString& result );
     void updateButton();
