@@ -49,6 +49,9 @@ signals:
 protected:
     Kita::PostInfo m_postInfo;
 
+protected slots:
+    virtual void reject();
+
 private:
     void fetchPostInfo( Kita::PostInfo* storage ) const;
 
