@@ -14,6 +14,7 @@
 #include <kfontdialog.h>
 #include <kcolordialog.h>
 #include <kpushbutton.h>
+#include <ktextedit.h>
 
 #include <qlayout.h>
 #include <qlabel.h>
@@ -23,6 +24,8 @@
 #include "kitafontprefbase.h"
 #include "kitaconfig.h"
 
+using namespace Kita;
+
 KitaPreferences::KitaPreferences()
         : KDialogBase( TreeList, i18n( "Kita Preferences" ),
                        Help | Default | Ok | Apply | Cancel, Ok )
@@ -41,6 +44,9 @@ KitaPreferences::KitaPreferences()
 
     QFrame * colorFrame = addPage( i18n( "Color" ), i18n( "Color" ) );
     m_colorPage = new KitaColorPrefPage( colorFrame );
+
+    QFrame * asciiArtFrame = addPage( i18n( "AsciiArt" ), i18n( "AsciiArt" ) );
+    m_asciiArtPage = new Kita::AsciiArtPrefPage( asciiArtFrame );
 }
 
 KitaFontPrefPage::KitaFontPrefPage( QWidget* parent )
@@ -155,4 +161,20 @@ void KitaColorPrefPage::slotChangeButtonClicked()
     }
 }
 
+AsciiArtPrefPage::AsciiArtPrefPage( QWidget* parent )
+        : AsciiArtPrefBase( parent )
+{
+    connect( saveButton, SIGNAL( clicked() ), SLOT( commit() ) );
+
+    asciiArtText->setText( KitaConfig::asciiArtList().join( "\n" ) );
+}
+
+void AsciiArtPrefPage::commit()
+{
+    QString text = asciiArtText->text();
+    QStringList list = QStringList::split( '\n', text );
+
+    KitaConfig::setAsciiArtList( list );
+}
+
 #include "pref.moc"
