@@ -16,10 +16,16 @@
 
 #include "kitafontprefbase.h"
 #include "kitacolorprefbase.h"
+#include "asciiartprefbase.h"
 
 class KitaFontPrefPage;
 class KitaColorPrefPage;
 
+namespace Kita
+{
+    class AsciiArtPrefPage;
+};
+
 class KitaPreferences : public KDialogBase
 {
     Q_OBJECT
@@ -30,6 +36,7 @@ public:
 private:
     KitaFontPrefPage* m_fontPage;
     KitaColorPrefPage* m_colorPage;
+    Kita::AsciiArtPrefPage* m_asciiArtPage;
 
 signals:
     void fontChanged( const QFont& );
@@ -66,4 +73,16 @@ public slots:
     void slotChangeButtonClicked();
 };
 
+namespace Kita
+{
+    class AsciiArtPrefPage : public AsciiArtPrefBase
+    {
+        Q_OBJECT
+    public:
+        AsciiArtPrefPage( QWidget* parent = 0 );
+    public slots:
+        void commit();
+    };
+};
+
 #endif // _KITAPREF_H_
