@@ -17,6 +17,7 @@
 #include <qtoolbutton.h>
 #include <qcombobox.h>
 #include <qregexp.h>
+#include <qheader.h>
 
 using namespace Kita;
 
@@ -25,6 +26,7 @@ ThreadListView::ThreadListView( QWidget* parent, const char* name )
 {
     SearchButton->setPixmap( SmallIcon( "find" ) );
     HideButton->setPixmap( SmallIcon( "filter" ) );
+    ReloadButton->setPixmap( SmallIcon( "reload" ) );
 
     subjectList->addColumn( "" );
     subjectList->addColumn( i18n( "No." ) );
@@ -33,11 +35,10 @@ ThreadListView::ThreadListView( QWidget* parent, const char* name )
     subjectList->addColumn( i18n( "ResNum" ) );
     subjectList->addColumn( i18n( "ReadNum" ) );
     subjectList->addColumn( i18n( "Unread" ) );
-    subjectList->addColumn( i18n( "Board" ) );
     subjectList->addColumn( i18n( "Since" ) );
 
-    subjectList->setColumnWidth( Row_Subject, 400 );
-    subjectList->setColumnWidthMode( Row_Subject, QListView::Manual );
+    subjectList->setColumnWidth( Col_Subject, 400 );
+    subjectList->setColumnWidthMode( Col_Subject, QListView::Manual );
 
     connect( SearchButton, SIGNAL( clicked() ),
              SLOT( slotSearchButton() ) );
@@ -47,7 +48,6 @@ ThreadListView::ThreadListView( QWidget* parent, const char* name )
              SLOT( slotHideButton( bool ) ) );
 }
 
-
 ThreadListView::~ThreadListView()
 {}
 
@@ -62,7 +62,7 @@ void ThreadListView::insertSearchCombo()
 {
     for ( int count = 0; count < SearchCombo->count(); ++count ) {
         if ( SearchCombo->text( count ) == SearchCombo->currentText() ) {
-            return;
+            return ;
         }
     }
     SearchCombo->insertItem( SearchCombo->currentText() );
@@ -83,17 +83,17 @@ QStringList ThreadListView::parseSearchQuery( const QString &input )
 
 void ThreadListView::searchNext( const QStringList &query )
 {
-    if ( query.isEmpty() ) return;
+    if ( query.isEmpty() ) return ;
 
     if ( query != m_prevquery ) {
         searchAll( query );
         slotHideButton( HideButton->isOn() );
         m_nextHitIndex = 0; //A next jump-search target reset to '0'.
-        return;
+        return ;
     }
 
     if ( m_nextHitIndex >= m_hitList.size() ) {
-        return;
+        return ;
     }
 
     KListViewItem* item = m_hitList[ m_nextHitIndex ];
@@ -110,13 +110,13 @@ void ThreadListView::searchAll( const QStringList &query )
 
     QListViewItemIterator listIt( subjectList );
     while ( listIt.current() != 0 ) {
-        KListViewItem* item = static_cast<KListViewItem*>( listIt.current() );
-        item->setPixmap( Row_Icon, 0 );
+        KListViewItem * item = static_cast<KListViewItem*>( listIt.current() );
+        item->setPixmap( Col_Icon, 0 );
 
         QStringList::const_iterator queryIt = query.begin();
         for ( ; queryIt != query.end(); ++queryIt ) {
-            if ( item->text( Row_Subject ).contains( *queryIt, false ) ) {
-                item->setPixmap( Row_Icon, SmallIcon( "find" ) );
+            if ( item->text( Col_Subject ).contains( *queryIt, false ) ) {
+                item->setPixmap( Col_Icon, SmallIcon( "find" ) );
                 m_hitList.append( item );
                 break;
             }
@@ -127,12 +127,12 @@ void ThreadListView::searchAll( const QStringList &query )
 
 void ThreadListView::slotHideButton( bool on )
 {
-    if ( m_hitList.empty() ) return;
+    if ( m_hitList.empty() ) return ;
 
     QListViewItemIterator listIt( subjectList );
     while ( listIt.current() != 0 ) {
-        KListViewItem* item = static_cast<KListViewItem *>( listIt.current() );
-        if ( on && ! item->pixmap( Row_Icon ) ) {
+        KListViewItem * item = static_cast<KListViewItem *>( listIt.current() );
+        if ( on && ! item->pixmap( Col_Icon ) ) {
             item->setVisible( false );
         } else {
             item->setVisible( true );
@@ -141,4 +141,18 @@ void ThreadListView::slotHideButton( bool on )
     }
 }
 
+int ThreadListViewItem::compare( QListViewItem* i, int col, bool ascending ) const
+{
+    switch ( col ) {
+    case Col_ResNum:
+    case Col_Read:
+    case Col_Unread:
+        return QString::localeAwareCompare( i->key( col, ascending ), key( col, ascending ) );
+    case Col_Mark:
+        return QString::localeAwareCompare( i->key( Col_MarkOrder, ascending ), key( Col_MarkOrder, ascending ) );
+    default:
+        return QString::localeAwareCompare( key( col, ascending ), i->key( col, ascending ) );
+    }
+}
+
 #include "threadlistview.moc"
