@@ -15,16 +15,17 @@
 #include <klistview.h>
 
 enum ThreadListViewRows {
-    Row_Mark,
-    Row_ID,
-    Row_Icon,
-    Row_Subject,
-    Row_ResNum,
-    Row_Read,
-    Row_Unread,
-    Row_Board,
-    Row_Since,
-    Row_DatURL
+    Col_Mark,
+    Col_ID,
+    Col_Icon,
+    Col_Subject,
+    Col_ResNum,
+    Col_Read,
+    Col_Unread,
+    Col_Since,
+    Col_Board,
+    Col_DatURL,
+    Col_MarkOrder
 };
 
 namespace Kita
@@ -57,6 +58,14 @@ namespace Kita
         void slotSearchButton();
     };
 
+    class ThreadListViewItem : public KListViewItem
+    {
+    public:
+        ThreadListViewItem( QListView* parent ) : KListViewItem( parent ) {};
+        virtual ~ThreadListViewItem() {};
+
+        virtual int compare( QListViewItem* i, int col, bool ascending ) const;
+    };
 };
 
 #endif
